pitcharraytools.PitchArrayRow
=============================

.. inheritance-diagram:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow
   :private-bases:

.. autoclass:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.cell_tokens

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.cell_widths

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.cells

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.depth

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.dimensions

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.is_defective

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.is_in_range

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.parent_array

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.pitches

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.row_index

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.weight

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.width

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.pitch_range

Methods
-------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.append

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.apply_pitches

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.copy_subrow

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.empty_pitches

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.extend

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.has_spanning_cell_over_index

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.index

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.merge

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.pad_to_width

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.pop

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.remove

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.withdraw

Special Methods
---------------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__add__

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__eq__

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__getitem__

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__iadd__

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__len__

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__ne__

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__repr__

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow.PitchArrayRow.__str__
